@@ -31,7 +31,6 @@ scan_error_occurred = False
 def get_scan_info():
     try:
         headers = {"Content-Type": "application/json"}
-        payload = {'projectId': config['projectid'], 'apiId': config['apiid']}
         resp = requests.post(SKEN_SERVER_BASE_URL + "/getScanData", headers=headers,data=json.dumps(config))
         global scan_info
         scan_info = resp.json()
@@ -84,8 +83,8 @@ def combine_args_config(sken_config):
     if parsed_args.api_id is not None:
         sken_config['apiid'] = parsed_args.api_id
 
-    if parsed_args.project_id is not None:
-        sken_config['projectid'] = parsed_args.project_id
+    if parsed_args.app_id is not None:
+        sken_config['appid'] = parsed_args.app_id
 
     if parsed_args.scanner is not None:
         sken_config['scanner'] = parsed_args.scanner
@@ -114,8 +113,8 @@ def precheck():
         print('Please specify "apiid" in sken.yaml or use --api_id flag.')
         exit(0)
     
-    if not 'projectid' in sken_config or sken_config['projectid'] is None:
-        print('Please specify "projectid" in sken.yaml or use --project_id flag.')
+    if not 'apiid' in sken_config or sken_config['apiid'] is None:
+        print('Please specify "appid" in sken.yaml or use --app_id flag.')
         exit(0)
 
     if not 'scanner' in sken_config or sken_config['scanner'] is None:
@@ -295,11 +294,11 @@ def upload_output(output_file, timing_file):
         s3 = session.resource('s3')
         file_name = ntpath.basename(output_file)
         data = open(output_file, 'rb')
-        s3.Bucket('sken-scanner-output').put_object(Key=config['projectid'] + '/' + timestamp + '/' + file_name, Body=data)
+        s3.Bucket('sken-scanner-output').put_object(Key=config['appid'] + '/' + timestamp + '/' + file_name, Body=data)
         
         file_name = ntpath.basename(timing_file)
         data = open(timing_file, 'rb')
-        s3.Bucket('sken-scanner-output').put_object(Key=config['projectid'] + '/' + timestamp + '/' + file_name, Body=data)
+        s3.Bucket('sken-scanner-output').put_object(Key=config['appid'] + '/' + timestamp + '/' + file_name, Body=data)
         print('Output file uploaded')
     except Exception as e:
         print('Failed to upload output file: ' + str(e))
@@ -309,7 +308,7 @@ def upload_output(output_file, timing_file):
 def trigger_etl(timestamp, fileName, scanner):
     print('ETL started')
     try:
-        payload = {'projectId': config['projectid'], 'apiId': config['apiid'], 'timestamp': timestamp, 'fileName': fileName, 'scanner': scanner}
+        payload = {'appId': config['appid'], 'apiId': config['apiid'], 'timestamp': timestamp, 'fileName': fileName, 'scanner': scanner}
         resp = requests.get(SKEN_SERVER_BASE_URL + "/doETL", params=payload)
         etl_result = resp.json()
 
@@ -330,8 +329,8 @@ def main():
     parser.add_argument('--dast_full_scan', metavar='DAST full scan', choices=['yes', 'no'], help='DAST full scan or quick scan.')
     parser.add_argument('--secrets', metavar='secrets config', help='secrets config.')
 
-    parser.add_argument('--api_id', metavar='API ID', help='API Id.')
-    parser.add_argument('--project_id', metavar='Project Id', help='Project Id.')
+    parser.add_argument('--api_id', metavar='API Id', help='API Id.')
+    parser.add_argument('--app_id', metavar='Application Id', help='Application Id.')
     global parsed_args
     parsed_args = parser.parse_args()
     
